@@ -237,6 +237,11 @@ seahorse_gedit_show_error (const gchar *heading, GError *error)
     g_assert (heading);
     g_assert (error);
     
+    /* Never show an error for 'cancelled' */
+    if (error->code == DBUS_GERROR_REMOTE_EXCEPTION && error->domain == DBUS_GERROR && 
+        strstr (dbus_g_error_get_name (error), "Cancelled"))
+	    return;
+    
     t = g_strconcat("<big><b>", heading, "</b></big>\n\n", 
                     error->message ? error->message : "", NULL);
     
@@ -418,8 +423,6 @@ decrypt_text (const gchar *text)
         return NULL;
     }
     
-g_printerr ("%s\n", text);    
-    
     ret = dbus_g_proxy_call (dbus_crypto_proxy, "DecryptText", &error,
                              G_TYPE_STRING, "openpgp",
                              G_TYPE_INT, 0,
